# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from cybee_sdk.api.models.exclude_larger_than import ExcludeLargerThan
from cybee_sdk.api.models.global_restic_options import GlobalResticOptions
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class ResticBackupInput(BaseModel):
    """
    ResticBackupInput
    """  # noqa: E501

    global_options: Optional[GlobalResticOptions] = None
    source_paths: Optional[List[StrictStr]] = None
    exclude: Optional[List[StrictStr]] = None
    exclude_caches: Optional[StrictBool] = False
    exclude_if_present: Optional[List[StrictStr]] = None
    exclude_larger_than: Optional[ExcludeLargerThan] = None
    iexclude: Optional[List[StrictStr]] = None
    __properties: ClassVar[List[str]] = [
        "global_options",
        "source_paths",
        "exclude",
        "exclude_caches",
        "exclude_if_present",
        "exclude_larger_than",
        "iexclude",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ResticBackupInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of global_options
        if self.global_options:
            _dict["global_options"] = self.global_options.to_dict()
        # override the default output from pydantic by calling `to_dict()` of exclude_larger_than
        if self.exclude_larger_than:
            _dict["exclude_larger_than"] = self.exclude_larger_than.to_dict()
        # set to None if global_options (nullable) is None
        # and model_fields_set contains the field
        if self.global_options is None and "global_options" in self.model_fields_set:
            _dict["global_options"] = None

        # set to None if source_paths (nullable) is None
        # and model_fields_set contains the field
        if self.source_paths is None and "source_paths" in self.model_fields_set:
            _dict["source_paths"] = None

        # set to None if exclude_larger_than (nullable) is None
        # and model_fields_set contains the field
        if self.exclude_larger_than is None and "exclude_larger_than" in self.model_fields_set:
            _dict["exclude_larger_than"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ResticBackupInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "global_options": GlobalResticOptions.from_dict(obj["global_options"])
                if obj.get("global_options") is not None
                else None,
                "source_paths": obj.get("source_paths"),
                "exclude": obj.get("exclude"),
                "exclude_caches": obj.get("exclude_caches") if obj.get("exclude_caches") is not None else False,
                "exclude_if_present": obj.get("exclude_if_present"),
                "exclude_larger_than": ExcludeLargerThan.from_dict(obj["exclude_larger_than"])
                if obj.get("exclude_larger_than") is not None
                else None,
                "iexclude": obj.get("iexclude"),
            }
        )
        return _obj



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from uuid import UUID
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class UnregisteredAgentInfo(BaseModel):
    """
    UnregisteredAgentInfo
    """  # noqa: E501

    id: UUID
    host_name: StrictStr
    domain_name: Optional[StrictStr] = None
    machine_id: StrictStr
    os_family: Optional[StrictStr] = None
    os_details: Optional[StrictStr] = None
    version: Optional[StrictStr] = None
    last_seen: datetime
    __properties: ClassVar[List[str]] = [
        "id",
        "host_name",
        "domain_name",
        "machine_id",
        "os_family",
        "os_details",
        "version",
        "last_seen",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UnregisteredAgentInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if domain_name (nullable) is None
        # and model_fields_set contains the field
        if self.domain_name is None and "domain_name" in self.model_fields_set:
            _dict["domain_name"] = None

        # set to None if os_family (nullable) is None
        # and model_fields_set contains the field
        if self.os_family is None and "os_family" in self.model_fields_set:
            _dict["os_family"] = None

        # set to None if os_details (nullable) is None
        # and model_fields_set contains the field
        if self.os_details is None and "os_details" in self.model_fields_set:
            _dict["os_details"] = None

        # set to None if version (nullable) is None
        # and model_fields_set contains the field
        if self.version is None and "version" in self.model_fields_set:
            _dict["version"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UnregisteredAgentInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "host_name": obj.get("host_name"),
                "domain_name": obj.get("domain_name"),
                "machine_id": obj.get("machine_id"),
                "os_family": obj.get("os_family"),
                "os_details": obj.get("os_details"),
                "version": obj.get("version"),
                "last_seen": obj.get("last_seen"),
            }
        )
        return _obj



# coding: utf-8

# flake8: noqa
"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from cybee_sdk.api.models.additional_agent_filter import AdditionalAgentFilter
from cybee_sdk.api.models.addr import Addr
from cybee_sdk.api.models.agent_info import AgentInfo
from cybee_sdk.api.models.agent_lock import AgentLock
from cybee_sdk.api.models.agent_notification_filter import AgentNotificationFilter
from cybee_sdk.api.models.agent_update import AgentUpdate
from cybee_sdk.api.models.api_key import ApiKey
from cybee_sdk.api.models.backup_error import BackupError
from cybee_sdk.api.models.backup_fatal_error import BackupFatalError
from cybee_sdk.api.models.backup_info import BackupInfo
from cybee_sdk.api.models.backup_notification_filter_input import BackupNotificationFilterInput
from cybee_sdk.api.models.backup_notification_filter_output import BackupNotificationFilterOutput
from cybee_sdk.api.models.backup_plan_error import BackupPlanError
from cybee_sdk.api.models.backup_plan_run import BackupPlanRun
from cybee_sdk.api.models.backup_status import BackupStatus
from cybee_sdk.api.models.backup_summary import BackupSummary
from cybee_sdk.api.models.backup_verbose_status import BackupVerboseStatus
from cybee_sdk.api.models.channel import Channel
from cybee_sdk.api.models.channel_create import ChannelCreate
from cybee_sdk.api.models.channel_type import ChannelType
from cybee_sdk.api.models.common_notify_filter import CommonNotifyFilter
from cybee_sdk.api.models.cores_group import CoresGroup
from cybee_sdk.api.models.create_scheduling import CreateScheduling
from cybee_sdk.api.models.cron_calendar import CronCalendar
from cybee_sdk.api.models.dns import Dns
from cybee_sdk.api.models.drive_type import DriveType
from cybee_sdk.api.models.exclude_larger_than import ExcludeLargerThan
from cybee_sdk.api.models.exclude_larger_than1 import ExcludeLargerThan1
from cybee_sdk.api.models.file_backup_plan import FileBackupPlan
from cybee_sdk.api.models.file_backup_plan_create import FileBackupPlanCreate
from cybee_sdk.api.models.file_backup_plan_update import FileBackupPlanUpdate
from cybee_sdk.api.models.file_restore_plan import FileRestorePlan
from cybee_sdk.api.models.file_restore_plan_create import FileRestorePlanCreate
from cybee_sdk.api.models.file_restore_plan_update import FileRestorePlanUpdate
from cybee_sdk.api.models.filesystem import Filesystem
from cybee_sdk.api.models.generate_key_request import GenerateKeyRequest
from cybee_sdk.api.models.generated_api_key import GeneratedApiKey
from cybee_sdk.api.models.global_restic_options import GlobalResticOptions
from cybee_sdk.api.models.http_validation_error import HTTPValidationError
from cybee_sdk.api.models.historical_machine import HistoricalMachine
from cybee_sdk.api.models.ip_version import IPVersion
from cybee_sdk.api.models.iface import Iface
from cybee_sdk.api.models.image_backup_plan import ImageBackupPlan
from cybee_sdk.api.models.image_backup_plan_create import ImageBackupPlanCreate
from cybee_sdk.api.models.image_backup_plan_extension import ImageBackupPlanExtension
from cybee_sdk.api.models.image_backup_plan_update import ImageBackupPlanUpdate
from cybee_sdk.api.models.image_restore_plan import ImageRestorePlan
from cybee_sdk.api.models.image_restore_plan_create import ImageRestorePlanCreate
from cybee_sdk.api.models.image_restore_plan_extension import ImageRestorePlanExtension
from cybee_sdk.api.models.image_restore_plan_update import ImageRestorePlanUpdate
from cybee_sdk.api.models.location_inner import LocationInner
from cybee_sdk.api.models.machine import Machine
from cybee_sdk.api.models.maintenance_status import MaintenanceStatus
from cybee_sdk.api.models.maintenance_type import MaintenanceType
from cybee_sdk.api.models.mass_storage import MassStorage
from cybee_sdk.api.models.memory import Memory
from cybee_sdk.api.models.notification_filter_input import NotificationFilterInput
from cybee_sdk.api.models.notification_filter_output import NotificationFilterOutput
from cybee_sdk.api.models.ntp import Ntp
from cybee_sdk.api.models.ntp_synchronized import NtpSynchronized
from cybee_sdk.api.models.organization import Organization
from cybee_sdk.api.models.os import Os
from cybee_sdk.api.models.page_agent_info import PageAgentInfo
from cybee_sdk.api.models.page_api_key import PageApiKey
from cybee_sdk.api.models.page_backup_plan_error import PageBackupPlanError
from cybee_sdk.api.models.page_backup_plan_run import PageBackupPlanRun
from cybee_sdk.api.models.page_channel import PageChannel
from cybee_sdk.api.models.page_file_backup_plan import PageFileBackupPlan
from cybee_sdk.api.models.page_file_restore_plan import PageFileRestorePlan
from cybee_sdk.api.models.page_historical_machine import PageHistoricalMachine
from cybee_sdk.api.models.page_image_backup_plan import PageImageBackupPlan
from cybee_sdk.api.models.page_image_restore_plan import PageImageRestorePlan
from cybee_sdk.api.models.page_machine import PageMachine
from cybee_sdk.api.models.page_organization import PageOrganization
from cybee_sdk.api.models.page_repository import PageRepository
from cybee_sdk.api.models.page_repository_checks import PageRepositoryChecks
from cybee_sdk.api.models.page_repository_prunes import PageRepositoryPrunes
from cybee_sdk.api.models.page_repository_stats import PageRepositoryStats
from cybee_sdk.api.models.page_restore_plan_error import PageRestorePlanError
from cybee_sdk.api.models.page_restore_plan_run import PageRestorePlanRun
from cybee_sdk.api.models.page_router import PageRouter
from cybee_sdk.api.models.page_scheduling import PageScheduling
from cybee_sdk.api.models.page_storage_account import PageStorageAccount
from cybee_sdk.api.models.page_storage_destination import PageStorageDestination
from cybee_sdk.api.models.page_template import PageTemplate
from cybee_sdk.api.models.page_unregistered_agent_info import PageUnregisteredAgentInfo
from cybee_sdk.api.models.partition import Partition
from cybee_sdk.api.models.phy_cpu import PhyCpu
from cybee_sdk.api.models.phy_drive import PhyDrive
from cybee_sdk.api.models.plan_status import PlanStatus
from cybee_sdk.api.models.plan_type import PlanType
from cybee_sdk.api.models.pre_post_run_script import PrePostRunScript
from cybee_sdk.api.models.pyd_generic_message import PydGenericMessage
from cybee_sdk.api.models.pyd_message_type import PydMessageType
from cybee_sdk.api.models.repository import Repository
from cybee_sdk.api.models.repository_checks import RepositoryChecks
from cybee_sdk.api.models.repository_create import RepositoryCreate
from cybee_sdk.api.models.repository_maintenance import RepositoryMaintenance
from cybee_sdk.api.models.repository_maintenance_create_update import RepositoryMaintenanceCreateUpdate
from cybee_sdk.api.models.repository_prunes import RepositoryPrunes
from cybee_sdk.api.models.repository_stats import RepositoryStats
from cybee_sdk.api.models.repository_status_enum import RepositoryStatusEnum
from cybee_sdk.api.models.repository_update import RepositoryUpdate
from cybee_sdk.api.models.restic_backup_input import ResticBackupInput
from cybee_sdk.api.models.restic_backup_output import ResticBackupOutput
from cybee_sdk.api.models.restic_restore import ResticRestore
from cybee_sdk.api.models.restic_stats_mode_enum import ResticStatsModeEnum
from cybee_sdk.api.models.restic_version_enum import ResticVersionEnum
from cybee_sdk.api.models.restoration_error import RestorationError
from cybee_sdk.api.models.restoration_info import RestorationInfo
from cybee_sdk.api.models.restoration_status import RestorationStatus
from cybee_sdk.api.models.restoration_summary import RestorationSummary
from cybee_sdk.api.models.restore_notification_filter_input import RestoreNotificationFilterInput
from cybee_sdk.api.models.restore_notification_filter_output import RestoreNotificationFilterOutput
from cybee_sdk.api.models.restore_plan_error import RestorePlanError
from cybee_sdk.api.models.restore_plan_run import RestorePlanRun
from cybee_sdk.api.models.restore_summary import RestoreSummary
from cybee_sdk.api.models.restore_verbose_status import RestoreVerboseStatus
from cybee_sdk.api.models.retention_settings import RetentionSettings
from cybee_sdk.api.models.router import Router
from cybee_sdk.api.models.router_create import RouterCreate
from cybee_sdk.api.models.router_update import RouterUpdate
from cybee_sdk.api.models.s3_provider import S3Provider
from cybee_sdk.api.models.s3_signature_version_enum import S3SignatureVersionEnum
from cybee_sdk.api.models.s3_storage_account_config import S3StorageAccountConfig
from cybee_sdk.api.models.scheduling import Scheduling
from cybee_sdk.api.models.scheduling_linked_plans import SchedulingLinkedPlans
from cybee_sdk.api.models.snapshot import Snapshot
from cybee_sdk.api.models.storage_account import StorageAccount
from cybee_sdk.api.models.storage_account_create import StorageAccountCreate
from cybee_sdk.api.models.storage_account_update import StorageAccountUpdate
from cybee_sdk.api.models.storage_destination import StorageDestination
from cybee_sdk.api.models.storage_destination_config import StorageDestinationConfig
from cybee_sdk.api.models.storage_destination_create import StorageDestinationCreate
from cybee_sdk.api.models.storage_destination_update import StorageDestinationUpdate
from cybee_sdk.api.models.storage_format import StorageFormat
from cybee_sdk.api.models.storage_notification_filter import StorageNotificationFilter
from cybee_sdk.api.models.template import Template
from cybee_sdk.api.models.template_create import TemplateCreate
from cybee_sdk.api.models.time_stamps import TimeStamps
from cybee_sdk.api.models.unregistered_agent_info import UnregisteredAgentInfo
from cybee_sdk.api.models.update_scheduling import UpdateScheduling
from cybee_sdk.api.models.validation_error import ValidationError
from cybee_sdk.api.models.zitadel_api_key_type import ZitadelApiKeyType



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.repository_maintenance import RepositoryMaintenance


class TestRepositoryMaintenance(unittest.TestCase):
    """RepositoryMaintenance unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RepositoryMaintenance:
        """Test RepositoryMaintenance
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `RepositoryMaintenance`
        """
        model = RepositoryMaintenance()
        if include_optional:
            return RepositoryMaintenance(
                prune_schedule = '0',
                latest_prune = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                prune_job_pipeline_id = '',
                check_schedule = '',
                latest_check = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                check_job_pipeline_id = ''
            )
        else:
            return RepositoryMaintenance(
        )
        """

    def testRepositoryMaintenance(self):
        """Test RepositoryMaintenance"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.retention_settings import RetentionSettings


class TestRetentionSettings(unittest.TestCase):
    """RetentionSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RetentionSettings:
        """Test RetentionSettings
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `RetentionSettings`
        """
        model = RetentionSettings()
        if include_optional:
            return RetentionSettings(
                keep_last = 0.0,
                keep_hourly = 0.0,
                keep_daily = 0.0,
                keep_weekly = 0.0,
                keep_monthly = 0.0,
                keep_yearly = 0.0,
                keep_within_as_secs = 0.0,
                keep_within_hourly_as_secs = 0.0,
                keep_within_daily_as_secs = 0.0,
                keep_within_weekly_as_secs = 0.0,
                keep_within_monthly_as_secs = 0.0,
                keep_within_yearly_as_secs = 0.0
            )
        else:
            return RetentionSettings(
        )
        """

    def testRetentionSettings(self):
        """Test RetentionSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from cybee_sdk.api.models.filesystem import Filesystem
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class Partition(BaseModel):
    """
    A slice of space on a mass storage. It is the raw space on which you may find a filesystem. However, not all partition contains a filesystem.  ## Fields definition:  - table_index: The idex of this partition in the partition table. - device_path: The (System depend) logical path to access this raw space. - system_required: Requiered by the operating system to boot successfully   (EFI partition, System reserved on windows, `/boot` on Linux, and root filesystem container).
    """  # noqa: E501

    id: StrictStr
    table_index: StrictInt
    device_path: StrictStr
    size: StrictInt
    offset: Optional[StrictInt] = None
    system_required: StrictBool
    content: Optional[Filesystem] = None
    __properties: ClassVar[List[str]] = [
        "id",
        "table_index",
        "device_path",
        "size",
        "offset",
        "system_required",
        "content",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Partition from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of content
        if self.content:
            _dict["content"] = self.content.to_dict()
        # set to None if offset (nullable) is None
        # and model_fields_set contains the field
        if self.offset is None and "offset" in self.model_fields_set:
            _dict["offset"] = None

        # set to None if content (nullable) is None
        # and model_fields_set contains the field
        if self.content is None and "content" in self.model_fields_set:
            _dict["content"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Partition from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "table_index": obj.get("table_index"),
                "device_path": obj.get("device_path"),
                "size": obj.get("size"),
                "offset": obj.get("offset"),
                "system_required": obj.get("system_required"),
                "content": Filesystem.from_dict(obj["content"]) if obj.get("content") is not None else None,
            }
        )
        return _obj



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.partition import Partition


class TestPartition(unittest.TestCase):
    """Partition unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Partition:
        """Test Partition
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Partition`
        """
        model = Partition()
        if include_optional:
            return Partition(
                id = '',
                table_index = 56,
                device_path = '',
                size = 56,
                offset = 56,
                system_required = True,
                content = cybee_sdk.api.models.filesystem.Filesystem(
                    name = '', 
                    filesystem = '', 
                    mount_points = [
                        ''
                        ], 
                    total_size = 56, 
                    available_space = 56, 
                    is_root = True, )
            )
        else:
            return Partition(
                id = '',
                table_index = 56,
                device_path = '',
                size = 56,
                system_required = True,
        )
        """

    def testPartition(self):
        """Test Partition"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.agents_api import AgentsApi


class TestAgentsApi(unittest.TestCase):
    """AgentsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AgentsApi()

    def tearDown(self) -> None:
        pass

    def test_approve_agent_agent_agent_id_approve_post(self) -> None:
        """Test case for approve_agent_agent_agent_id_approve_post

        Approve Agent
        """
        pass

    def test_delete_agent_agent_agent_id_delete(self) -> None:
        """Test case for delete_agent_agent_agent_id_delete

        Delete Agent
        """
        pass

    def test_get_agent_agent_unregistered_get(self) -> None:
        """Test case for get_agent_agent_unregistered_get

        Get Agent
        """
        pass

    def test_list_agent_agent_get(self) -> None:
        """Test case for list_agent_agent_get

        List Agent
        """
        pass

    def test_lock_agent_agent_agent_id_lock_post(self) -> None:
        """Test case for lock_agent_agent_agent_id_lock_post

        Lock Agent
        """
        pass

    def test_unlock_agent_agent_agent_id_unlock_post(self) -> None:
        """Test case for unlock_agent_agent_agent_id_unlock_post

        Unlock Agent
        """
        pass

    def test_update_agent_agent_agent_id_put(self) -> None:
        """Test case for update_agent_agent_agent_id_put

        Update Agent
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.mass_storage import MassStorage


class TestMassStorage(unittest.TestCase):
    """MassStorage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MassStorage:
        """Test MassStorage
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `MassStorage`
        """
        model = MassStorage()
        if include_optional:
            return MassStorage(
                storage_format = None,
                id = '',
                device_path = '',
                name = '',
                total_size = 56,
                largest_free_space = 56,
                support = cybee_sdk.api.models.phy_drive.PhyDrive(
                    size = 56, 
                    drive_type = null, 
                    name = '', ),
                content = [
                    cybee_sdk.api.models.partition.Partition(
                        id = '', 
                        table_index = 56, 
                        device_path = '', 
                        size = 56, 
                        offset = 56, 
                        system_required = True, )
                    ]
            )
        else:
            return MassStorage(
                storage_format = None,
                id = '',
                device_path = '',
                name = '',
                total_size = 56,
                largest_free_space = 56,
        )
        """

    def testMassStorage(self):
        """Test MassStorage"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from cybee_sdk.api.models.repository_stats import RepositoryStats
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class PageRepositoryStats(BaseModel):
    """
    PageRepositoryStats
    """  # noqa: E501

    page: StrictInt
    per_page: StrictInt
    total_items: StrictInt
    total_pages: Optional[StrictInt] = None
    items: List[RepositoryStats]
    __properties: ClassVar[List[str]] = ["page", "per_page", "total_items", "total_pages", "items"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PageRepositoryStats from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in items (list)
        _items = []
        if self.items:
            for _item_items in self.items:
                if _item_items:
                    _items.append(_item_items.to_dict())
            _dict["items"] = _items
        # set to None if total_pages (nullable) is None
        # and model_fields_set contains the field
        if self.total_pages is None and "total_pages" in self.model_fields_set:
            _dict["total_pages"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PageRepositoryStats from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "page": obj.get("page"),
                "per_page": obj.get("per_page"),
                "total_items": obj.get("total_items"),
                "total_pages": obj.get("total_pages"),
                "items": [RepositoryStats.from_dict(_item) for _item in obj["items"]]
                if obj.get("items") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from cybee_sdk.api.models.dns import Dns
from cybee_sdk.api.models.filesystem import Filesystem
from cybee_sdk.api.models.iface import Iface
from cybee_sdk.api.models.mass_storage import MassStorage
from cybee_sdk.api.models.memory import Memory
from cybee_sdk.api.models.ntp import Ntp
from cybee_sdk.api.models.os import Os
from cybee_sdk.api.models.phy_cpu import PhyCpu
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class Machine(BaseModel):
    """
    Machine
    """  # noqa: E501

    machine_id: StrictStr
    cpus: Optional[List[PhyCpu]] = None
    os: Optional[Os] = None
    mass_storage: Optional[List[MassStorage]] = None
    filesystems: Optional[List[Filesystem]] = None
    ifaces: Optional[List[Iface]] = None
    dns: Optional[List[Dns]] = None
    ntp: Optional[Ntp] = None
    memory: Optional[Memory] = None
    created_at: datetime
    changed_at: datetime
    updated_at: datetime
    __properties: ClassVar[List[str]] = [
        "machine_id",
        "cpus",
        "os",
        "mass_storage",
        "filesystems",
        "ifaces",
        "dns",
        "ntp",
        "memory",
        "created_at",
        "changed_at",
        "updated_at",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Machine from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in cpus (list)
        _items = []
        if self.cpus:
            for _item_cpus in self.cpus:
                if _item_cpus:
                    _items.append(_item_cpus.to_dict())
            _dict["cpus"] = _items
        # override the default output from pydantic by calling `to_dict()` of os
        if self.os:
            _dict["os"] = self.os.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in mass_storage (list)
        _items = []
        if self.mass_storage:
            for _item_mass_storage in self.mass_storage:
                if _item_mass_storage:
                    _items.append(_item_mass_storage.to_dict())
            _dict["mass_storage"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in filesystems (list)
        _items = []
        if self.filesystems:
            for _item_filesystems in self.filesystems:
                if _item_filesystems:
                    _items.append(_item_filesystems.to_dict())
            _dict["filesystems"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in ifaces (list)
        _items = []
        if self.ifaces:
            for _item_ifaces in self.ifaces:
                if _item_ifaces:
                    _items.append(_item_ifaces.to_dict())
            _dict["ifaces"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in dns (list)
        _items = []
        if self.dns:
            for _item_dns in self.dns:
                if _item_dns:
                    _items.append(_item_dns.to_dict())
            _dict["dns"] = _items
        # override the default output from pydantic by calling `to_dict()` of ntp
        if self.ntp:
            _dict["ntp"] = self.ntp.to_dict()
        # override the default output from pydantic by calling `to_dict()` of memory
        if self.memory:
            _dict["memory"] = self.memory.to_dict()
        # set to None if cpus (nullable) is None
        # and model_fields_set contains the field
        if self.cpus is None and "cpus" in self.model_fields_set:
            _dict["cpus"] = None

        # set to None if os (nullable) is None
        # and model_fields_set contains the field
        if self.os is None and "os" in self.model_fields_set:
            _dict["os"] = None

        # set to None if mass_storage (nullable) is None
        # and model_fields_set contains the field
        if self.mass_storage is None and "mass_storage" in self.model_fields_set:
            _dict["mass_storage"] = None

        # set to None if filesystems (nullable) is None
        # and model_fields_set contains the field
        if self.filesystems is None and "filesystems" in self.model_fields_set:
            _dict["filesystems"] = None

        # set to None if ifaces (nullable) is None
        # and model_fields_set contains the field
        if self.ifaces is None and "ifaces" in self.model_fields_set:
            _dict["ifaces"] = None

        # set to None if dns (nullable) is None
        # and model_fields_set contains the field
        if self.dns is None and "dns" in self.model_fields_set:
            _dict["dns"] = None

        # set to None if ntp (nullable) is None
        # and model_fields_set contains the field
        if self.ntp is None and "ntp" in self.model_fields_set:
            _dict["ntp"] = None

        # set to None if memory (nullable) is None
        # and model_fields_set contains the field
        if self.memory is None and "memory" in self.model_fields_set:
            _dict["memory"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Machine from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "machine_id": obj.get("machine_id"),
                "cpus": [PhyCpu.from_dict(_item) for _item in obj["cpus"]] if obj.get("cpus") is not None else None,
                "os": Os.from_dict(obj["os"]) if obj.get("os") is not None else None,
                "mass_storage": [MassStorage.from_dict(_item) for _item in obj["mass_storage"]]
                if obj.get("mass_storage") is not None
                else None,
                "filesystems": [Filesystem.from_dict(_item) for _item in obj["filesystems"]]
                if obj.get("filesystems") is not None
                else None,
                "ifaces": [Iface.from_dict(_item) for _item in obj["ifaces"]]
                if obj.get("ifaces") is not None
                else None,
                "dns": [Dns.from_dict(_item) for _item in obj["dns"]] if obj.get("dns") is not None else None,
                "ntp": Ntp.from_dict(obj["ntp"]) if obj.get("ntp") is not None else None,
                "memory": Memory.from_dict(obj["memory"]) if obj.get("memory") is not None else None,
                "created_at": obj.get("created_at"),
                "changed_at": obj.get("changed_at"),
                "updated_at": obj.get("updated_at"),
            }
        )
        return _obj



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.restic_backup_input import ResticBackupInput


class TestResticBackupInput(unittest.TestCase):
    """ResticBackupInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResticBackupInput:
        """Test ResticBackupInput
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `ResticBackupInput`
        """
        model = ResticBackupInput()
        if include_optional:
            return ResticBackupInput(
                global_options = cybee_sdk.api.models.global_restic_options.GlobalResticOptions(
                    cache_dir = '', 
                    limit_download = 0.0, 
                    limit_upload = 0.0, ),
                source_paths = [
                    ''
                    ],
                exclude = [
                    ''
                    ],
                exclude_caches = True,
                exclude_if_present = [
                    ''
                    ],
                exclude_larger_than = None,
                iexclude = [
                    ''
                    ]
            )
        else:
            return ResticBackupInput(
        )
        """

    def testResticBackupInput(self):
        """Test ResticBackupInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.snapshot import Snapshot


class TestSnapshot(unittest.TestCase):
    """Snapshot unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Snapshot:
        """Test Snapshot
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Snapshot`
        """
        model = Snapshot()
        if include_optional:
            return Snapshot(
                id = '',
                files_new = 0.0,
                files_changed = 0.0,
                files_unmodified = 0.0,
                dirs_new = 0.0,
                dirs_changed = 0.0,
                dirs_unmodified = 0.0,
                data_blobs = 0.0,
                tree_blobs = 0.0,
                data_added = 0.0,
                data_added_packed = 0.0,
                total_files_processed = 0.0,
                total_bytes_processed = 0.0,
                total_duration = 0.0,
                snapshot_id = '',
                backup_paths = [
                    ''
                    ]
            )
        else:
            return Snapshot(
                id = '',
        )
        """

    def testSnapshot(self):
        """Test Snapshot"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.image_restore_plan_create import ImageRestorePlanCreate


class TestImageRestorePlanCreate(unittest.TestCase):
    """ImageRestorePlanCreate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ImageRestorePlanCreate:
        """Test ImageRestorePlanCreate
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `ImageRestorePlanCreate`
        """
        model = ImageRestorePlanCreate()
        if include_optional:
            return ImageRestorePlanCreate(
                name = '0',
                description = '0',
                repo_id = '',
                config = cybee_sdk.api.models.restic_restore.ResticRestore(
                    global_options = cybee_sdk.api.models.global_restic_options.GlobalResticOptions(
                        cache_dir = '', 
                        limit_download = 0.0, 
                        limit_upload = 0.0, ), 
                    exclude = [
                        ''
                        ], 
                    include = [
                        ''
                        ], 
                    iexclude = [
                        ''
                        ], 
                    iinclude = [
                        ''
                        ], 
                    host = '', 
                    path = '', 
                    tag = [
                        ''
                        ], 
                    sparse = True, 
                    target = '', 
                    verify = True, 
                    snapshot_id = '', ),
                schedule_enabled = True,
                schedule_configs = [
                    ''
                    ],
                affected_agents = [
                    ''
                    ],
                extension = cybee_sdk.api.models.image_backup_plan_extension.ImageBackupPlanExtension(
                    partitions = {
                        'key' : [
                            56
                            ]
                        }, ),
                pre_script = cybee_sdk.api.models.pre_post_run_script.PrePostRunScript(
                    executor = '', 
                    args = [
                        ''
                        ], 
                    envs = {
                        'key' : ''
                        }, 
                    script_path = '', 
                    script = '', 
                    abort_if_fail = True, ),
                post_script = cybee_sdk.api.models.pre_post_run_script.PrePostRunScript(
                    executor = '', 
                    args = [
                        ''
                        ], 
                    envs = {
                        'key' : ''
                        }, 
                    script_path = '', 
                    script = '', 
                    abort_if_fail = True, )
            )
        else:
            return ImageRestorePlanCreate(
                name = '0',
                repo_id = '',
                config = cybee_sdk.api.models.restic_restore.ResticRestore(
                    global_options = cybee_sdk.api.models.global_restic_options.GlobalResticOptions(
                        cache_dir = '', 
                        limit_download = 0.0, 
                        limit_upload = 0.0, ), 
                    exclude = [
                        ''
                        ], 
                    include = [
                        ''
                        ], 
                    iexclude = [
                        ''
                        ], 
                    iinclude = [
                        ''
                        ], 
                    host = '', 
                    path = '', 
                    tag = [
                        ''
                        ], 
                    sparse = True, 
                    target = '', 
                    verify = True, 
                    snapshot_id = '', ),
                extension = cybee_sdk.api.models.image_backup_plan_extension.ImageBackupPlanExtension(
                    partitions = {
                        'key' : [
                            56
                            ]
                        }, ),
        )
        """

    def testImageRestorePlanCreate(self):
        """Test ImageRestorePlanCreate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.backup_plan_run import BackupPlanRun


class TestBackupPlanRun(unittest.TestCase):
    """BackupPlanRun unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BackupPlanRun:
        """Test BackupPlanRun
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `BackupPlanRun`
        """
        model = BackupPlanRun()
        if include_optional:
            return BackupPlanRun(
                id = '',
                task_id = '',
                snapshot_id = '',
                agent_id = '',
                programmed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                repository_id = '',
                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                plan_config = '',
                plan_id = '',
                plan_type = '',
                status = 'finished',
                snapshots = [
                    cybee_sdk.api.models.snapshot.Snapshot(
                        id = '', 
                        files_new = 0.0, 
                        files_changed = 0.0, 
                        files_unmodified = 0.0, 
                        dirs_new = 0.0, 
                        dirs_changed = 0.0, 
                        dirs_unmodified = 0.0, 
                        data_blobs = 0.0, 
                        tree_blobs = 0.0, 
                        data_added = 0.0, 
                        data_added_packed = 0.0, 
                        total_files_processed = 0.0, 
                        total_bytes_processed = 0.0, 
                        total_duration = 0.0, 
                        snapshot_id = '', 
                        backup_paths = [
                            ''
                            ], )
                    ],
                errors = [
                    ''
                    ]
            )
        else:
            return BackupPlanRun(
                id = '',
                agent_id = '',
                repository_id = '',
                plan_id = '',
                plan_type = '',
        )
        """

    def testBackupPlanRun(self):
        """Test BackupPlanRun"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from cybee_sdk.api.models.partition import Partition
from cybee_sdk.api.models.phy_drive import PhyDrive
from cybee_sdk.api.models.storage_format import StorageFormat
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class MassStorage(BaseModel):
    """
    A raw space generaly backed by a physical drive. It could also be the representation of a pool of drives or RAID. That is the space on which you find the partition table.  In a image backup / restoration context, it is the lower emptity you may list and on which you can select what to backup / restore.  ## Fields definition:  - device_path: The (System depend) logical path to access this raw space. - support: The logical or physical represetentation of the abstraction given by this object.   It's generaly a physical drive or a RAID but may also be composed by virtual raw spaces. - largest_free_space: The largest contigous space available on this storage.   It can be seen as the biggest size usable for a new partition.
    """  # noqa: E501

    storage_format: StorageFormat
    id: StrictStr
    device_path: StrictStr
    name: StrictStr
    total_size: StrictInt
    largest_free_space: StrictInt
    support: Optional[PhyDrive] = None
    content: Optional[List[Partition]] = None
    __properties: ClassVar[List[str]] = [
        "storage_format",
        "id",
        "device_path",
        "name",
        "total_size",
        "largest_free_space",
        "support",
        "content",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MassStorage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of storage_format
        if self.storage_format:
            _dict["storage_format"] = self.storage_format.to_dict()
        # override the default output from pydantic by calling `to_dict()` of support
        if self.support:
            _dict["support"] = self.support.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in content (list)
        _items = []
        if self.content:
            for _item_content in self.content:
                if _item_content:
                    _items.append(_item_content.to_dict())
            _dict["content"] = _items
        # set to None if support (nullable) is None
        # and model_fields_set contains the field
        if self.support is None and "support" in self.model_fields_set:
            _dict["support"] = None

        # set to None if content (nullable) is None
        # and model_fields_set contains the field
        if self.content is None and "content" in self.model_fields_set:
            _dict["content"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MassStorage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "storage_format": StorageFormat.from_dict(obj["storage_format"])
                if obj.get("storage_format") is not None
                else None,
                "id": obj.get("id"),
                "device_path": obj.get("device_path"),
                "name": obj.get("name"),
                "total_size": obj.get("total_size"),
                "largest_free_space": obj.get("largest_free_space"),
                "support": PhyDrive.from_dict(obj["support"]) if obj.get("support") is not None else None,
                "content": [Partition.from_dict(_item) for _item in obj["content"]]
                if obj.get("content") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from uuid import UUID
from cybee_sdk.api.models.plan_status import PlanStatus
from cybee_sdk.api.models.restore_summary import RestoreSummary
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class RestorePlanRun(BaseModel):
    """
    RestorePlanRun
    """  # noqa: E501

    id: UUID
    task_id: Optional[UUID] = None
    snapshot_id: Optional[StrictStr] = None
    agent_id: UUID
    programmed_at: Optional[datetime] = None
    repository_id: UUID
    started_at: datetime
    finished_at: Optional[datetime] = None
    plan_config: Optional[StrictStr] = None
    plan_id: UUID
    plan_type: StrictStr
    status: Optional[PlanStatus] = None
    restore_summary: Optional[RestoreSummary] = None
    errors: Optional[List[UUID]] = None
    __properties: ClassVar[List[str]] = [
        "id",
        "task_id",
        "snapshot_id",
        "agent_id",
        "programmed_at",
        "repository_id",
        "started_at",
        "finished_at",
        "plan_config",
        "plan_id",
        "plan_type",
        "status",
        "restore_summary",
        "errors",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RestorePlanRun from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of restore_summary
        if self.restore_summary:
            _dict["restore_summary"] = self.restore_summary.to_dict()
        # set to None if task_id (nullable) is None
        # and model_fields_set contains the field
        if self.task_id is None and "task_id" in self.model_fields_set:
            _dict["task_id"] = None

        # set to None if snapshot_id (nullable) is None
        # and model_fields_set contains the field
        if self.snapshot_id is None and "snapshot_id" in self.model_fields_set:
            _dict["snapshot_id"] = None

        # set to None if programmed_at (nullable) is None
        # and model_fields_set contains the field
        if self.programmed_at is None and "programmed_at" in self.model_fields_set:
            _dict["programmed_at"] = None

        # set to None if finished_at (nullable) is None
        # and model_fields_set contains the field
        if self.finished_at is None and "finished_at" in self.model_fields_set:
            _dict["finished_at"] = None

        # set to None if plan_config (nullable) is None
        # and model_fields_set contains the field
        if self.plan_config is None and "plan_config" in self.model_fields_set:
            _dict["plan_config"] = None

        # set to None if restore_summary (nullable) is None
        # and model_fields_set contains the field
        if self.restore_summary is None and "restore_summary" in self.model_fields_set:
            _dict["restore_summary"] = None

        # set to None if errors (nullable) is None
        # and model_fields_set contains the field
        if self.errors is None and "errors" in self.model_fields_set:
            _dict["errors"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RestorePlanRun from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "task_id": obj.get("task_id"),
                "snapshot_id": obj.get("snapshot_id"),
                "agent_id": obj.get("agent_id"),
                "programmed_at": obj.get("programmed_at"),
                "repository_id": obj.get("repository_id"),
                "started_at": obj.get("started_at"),
                "finished_at": obj.get("finished_at"),
                "plan_config": obj.get("plan_config"),
                "plan_id": obj.get("plan_id"),
                "plan_type": obj.get("plan_type"),
                "status": obj.get("status"),
                "restore_summary": RestoreSummary.from_dict(obj["restore_summary"])
                if obj.get("restore_summary") is not None
                else None,
                "errors": obj.get("errors"),
            }
        )
        return _obj



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ZitadelApiKeyType(str, Enum):
    """
    ZitadelApiKeyType
    """

    """
    allowed enum values
    """
    JWT = "jwt"
    PAT = "pat"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ZitadelApiKeyType from a JSON string"""
        return cls(json.loads(json_str))



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from uuid import UUID
from cybee_sdk.api.models.time_stamps import TimeStamps
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class AgentInfo(BaseModel):
    """
    AgentInfo
    """  # noqa: E501

    id: UUID
    version: Optional[StrictStr] = None
    machine_id: StrictStr
    host_name: StrictStr
    domain_name: Optional[StrictStr] = None
    custom_name: Optional[StrictStr] = None
    online: Optional[StrictBool] = None
    approved_at: Optional[datetime] = None
    last_seen: datetime
    lock_reason: Optional[StrictStr] = None
    locked_at: Optional[datetime] = None
    timestamps: TimeStamps
    __properties: ClassVar[List[str]] = [
        "id",
        "version",
        "machine_id",
        "host_name",
        "domain_name",
        "custom_name",
        "online",
        "approved_at",
        "last_seen",
        "lock_reason",
        "locked_at",
        "timestamps",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AgentInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of timestamps
        if self.timestamps:
            _dict["timestamps"] = self.timestamps.to_dict()
        # set to None if version (nullable) is None
        # and model_fields_set contains the field
        if self.version is None and "version" in self.model_fields_set:
            _dict["version"] = None

        # set to None if domain_name (nullable) is None
        # and model_fields_set contains the field
        if self.domain_name is None and "domain_name" in self.model_fields_set:
            _dict["domain_name"] = None

        # set to None if custom_name (nullable) is None
        # and model_fields_set contains the field
        if self.custom_name is None and "custom_name" in self.model_fields_set:
            _dict["custom_name"] = None

        # set to None if online (nullable) is None
        # and model_fields_set contains the field
        if self.online is None and "online" in self.model_fields_set:
            _dict["online"] = None

        # set to None if approved_at (nullable) is None
        # and model_fields_set contains the field
        if self.approved_at is None and "approved_at" in self.model_fields_set:
            _dict["approved_at"] = None

        # set to None if lock_reason (nullable) is None
        # and model_fields_set contains the field
        if self.lock_reason is None and "lock_reason" in self.model_fields_set:
            _dict["lock_reason"] = None

        # set to None if locked_at (nullable) is None
        # and model_fields_set contains the field
        if self.locked_at is None and "locked_at" in self.model_fields_set:
            _dict["locked_at"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AgentInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "version": obj.get("version"),
                "machine_id": obj.get("machine_id"),
                "host_name": obj.get("host_name"),
                "domain_name": obj.get("domain_name"),
                "custom_name": obj.get("custom_name"),
                "online": obj.get("online"),
                "approved_at": obj.get("approved_at"),
                "last_seen": obj.get("last_seen"),
                "lock_reason": obj.get("lock_reason"),
                "locked_at": obj.get("locked_at"),
                "timestamps": TimeStamps.from_dict(obj["timestamps"]) if obj.get("timestamps") is not None else None,
            }
        )
        return _obj



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.page_machine import PageMachine


class TestPageMachine(unittest.TestCase):
    """PageMachine unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageMachine:
        """Test PageMachine
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `PageMachine`
        """
        model = PageMachine()
        if include_optional:
            return PageMachine(
                page = 56,
                per_page = 56,
                total_items = 56,
                total_pages = 56,
                items = [
                    cybee_sdk.api.models.machine.Machine(
                        machine_id = '', 
                        cpus = [
                            cybee_sdk.api.models.phy_cpu.PhyCpu(
                                vendor = '', 
                                brand = '', 
                                architecture = '', 
                                cores = [
                                    cybee_sdk.api.models.cores_group.CoresGroup(
                                        variant = '', 
                                        cores_count = 56, 
                                        threads_per_core = 56, 
                                        freq = 1.337, )
                                    ], )
                            ], 
                        os = null, 
                        mass_storage = [
                            cybee_sdk.api.models.mass_storage.MassStorage(
                                storage_format = null, 
                                id = '', 
                                device_path = '', 
                                name = '', 
                                total_size = 56, 
                                largest_free_space = 56, 
                                support = null, 
                                content = [
                                    cybee_sdk.api.models.partition.Partition(
                                        id = '', 
                                        table_index = 56, 
                                        device_path = '', 
                                        size = 56, 
                                        offset = 56, 
                                        system_required = True, )
                                    ], )
                            ], 
                        filesystems = [
                            cybee_sdk.api.models.filesystem.Filesystem(
                                name = '', 
                                filesystem = '', 
                                mount_points = [
                                    ''
                                    ], 
                                total_size = 56, 
                                available_space = 56, 
                                is_root = True, )
                            ], 
                        ifaces = [
                            cybee_sdk.api.models.iface.Iface(
                                mac_address = '', 
                                ip_addresses = [
                                    cybee_sdk.api.models.addr.Addr(
                                        ip_version = 'V4', 
                                        ip = '', 
                                        broadcast = '', 
                                        netmask = '', )
                                    ], 
                                name = '', )
                            ], 
                        dns = [
                            cybee_sdk.api.models.dns.Dns(
                                hostname = '', )
                            ], 
                        ntp = null, 
                        memory = null, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        changed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return PageMachine(
                page = 56,
                per_page = 56,
                total_items = 56,
                items = [
                    cybee_sdk.api.models.machine.Machine(
                        machine_id = '', 
                        cpus = [
                            cybee_sdk.api.models.phy_cpu.PhyCpu(
                                vendor = '', 
                                brand = '', 
                                architecture = '', 
                                cores = [
                                    cybee_sdk.api.models.cores_group.CoresGroup(
                                        variant = '', 
                                        cores_count = 56, 
                                        threads_per_core = 56, 
                                        freq = 1.337, )
                                    ], )
                            ], 
                        os = null, 
                        mass_storage = [
                            cybee_sdk.api.models.mass_storage.MassStorage(
                                storage_format = null, 
                                id = '', 
                                device_path = '', 
                                name = '', 
                                total_size = 56, 
                                largest_free_space = 56, 
                                support = null, 
                                content = [
                                    cybee_sdk.api.models.partition.Partition(
                                        id = '', 
                                        table_index = 56, 
                                        device_path = '', 
                                        size = 56, 
                                        offset = 56, 
                                        system_required = True, )
                                    ], )
                            ], 
                        filesystems = [
                            cybee_sdk.api.models.filesystem.Filesystem(
                                name = '', 
                                filesystem = '', 
                                mount_points = [
                                    ''
                                    ], 
                                total_size = 56, 
                                available_space = 56, 
                                is_root = True, )
                            ], 
                        ifaces = [
                            cybee_sdk.api.models.iface.Iface(
                                mac_address = '', 
                                ip_addresses = [
                                    cybee_sdk.api.models.addr.Addr(
                                        ip_version = 'V4', 
                                        ip = '', 
                                        broadcast = '', 
                                        netmask = '', )
                                    ], 
                                name = '', )
                            ], 
                        dns = [
                            cybee_sdk.api.models.dns.Dns(
                                hostname = '', )
                            ], 
                        ntp = null, 
                        memory = null, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        changed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
        )
        """

    def testPageMachine(self):
        """Test PageMachine"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from cybee_sdk.api.models.s3_signature_version_enum import S3SignatureVersionEnum
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class S3StorageAccountConfig(BaseModel):
    """
    S3StorageAccountConfig
    """  # noqa: E501

    access_key: StrictStr
    secret_key: StrictStr
    signature_version: S3SignatureVersionEnum
    http_endpoint: Optional[StrictStr] = None
    https_endpoint: Optional[StrictStr] = None
    ignore_ssl: Optional[StrictBool] = False
    __properties: ClassVar[List[str]] = [
        "access_key",
        "secret_key",
        "signature_version",
        "http_endpoint",
        "https_endpoint",
        "ignore_ssl",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of S3StorageAccountConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if http_endpoint (nullable) is None
        # and model_fields_set contains the field
        if self.http_endpoint is None and "http_endpoint" in self.model_fields_set:
            _dict["http_endpoint"] = None

        # set to None if https_endpoint (nullable) is None
        # and model_fields_set contains the field
        if self.https_endpoint is None and "https_endpoint" in self.model_fields_set:
            _dict["https_endpoint"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of S3StorageAccountConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "access_key": obj.get("access_key"),
                "secret_key": obj.get("secret_key"),
                "signature_version": obj.get("signature_version"),
                "http_endpoint": obj.get("http_endpoint"),
                "https_endpoint": obj.get("https_endpoint"),
                "ignore_ssl": obj.get("ignore_ssl") if obj.get("ignore_ssl") is not None else False,
            }
        )
        return _obj



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.plans_restore_api import PlansRestoreApi


class TestPlansRestoreApi(unittest.TestCase):
    """PlansRestoreApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PlansRestoreApi()

    def tearDown(self) -> None:
        pass

    def test_assign_restore_plan_agent_plan_restore_plan_id_assign_agent_agent_id_post(self) -> None:
        """Test case for assign_restore_plan_agent_plan_restore_plan_id_assign_agent_agent_id_post

        Assign Restore Plan Agent
        """
        pass

    def test_assign_restore_plan_schedule_plan_restore_plan_id_assign_schedule_schedule_id_post(self) -> None:
        """Test case for assign_restore_plan_schedule_plan_restore_plan_id_assign_schedule_schedule_id_post

        Assign Restore Plan Schedule
        """
        pass

    def test_cancel_running_restore_plan_plan_restore_run_restore_plan_run_id_cancel_put(self) -> None:
        """Test case for cancel_running_restore_plan_plan_restore_run_restore_plan_run_id_cancel_put

        Cancel Running Restore Plan
        """
        pass

    def test_create_file_restore_plans_plan_restore_file_post(self) -> None:
        """Test case for create_file_restore_plans_plan_restore_file_post

        Create File Restore Plans
        """
        pass

    def test_create_image_restore_plans_plan_restore_image_post(self) -> None:
        """Test case for create_image_restore_plans_plan_restore_image_post

        Create Image Restore Plans
        """
        pass

    def test_delete_file_restore_plans_plan_restore_file_plan_id_delete(self) -> None:
        """Test case for delete_file_restore_plans_plan_restore_file_plan_id_delete

        Delete File Restore Plans
        """
        pass

    def test_delete_image_restore_plans_plan_restore_image_plan_id_delete(self) -> None:
        """Test case for delete_image_restore_plans_plan_restore_image_plan_id_delete

        Delete Image Restore Plans
        """
        pass

    def test_execute_file_restore_plan_plan_restore_file_plan_id_execute_post(self) -> None:
        """Test case for execute_file_restore_plan_plan_restore_file_plan_id_execute_post

        Execute File Restore Plan
        """
        pass

    def test_execute_image_restore_plan_plan_restore_image_plan_id_execute_post(self) -> None:
        """Test case for execute_image_restore_plan_plan_restore_image_plan_id_execute_post

        Execute Image Restore Plan
        """
        pass

    def test_get_running_plan_status_plan_restore_run_plan_run_id_status_get(self) -> None:
        """Test case for get_running_plan_status_plan_restore_run_plan_run_id_status_get

        Get Running Plan Status
        """
        pass

    def test_list_all_latest_restore_history_plan_restore_history_latest_get(self) -> None:
        """Test case for list_all_latest_restore_history_plan_restore_history_latest_get

        List All Latest Restore History
        """
        pass

    def test_list_all_restore_history_error_plan_restore_history_error_get(self) -> None:
        """Test case for list_all_restore_history_error_plan_restore_history_error_get

        List All Restore History Error
        """
        pass

    def test_list_all_restore_history_plan_restore_history_get(self) -> None:
        """Test case for list_all_restore_history_plan_restore_history_get

        List All Restore History
        """
        pass

    def test_list_file_restore_plans_plan_restore_file_get(self) -> None:
        """Test case for list_file_restore_plans_plan_restore_file_get

        List File Restore Plans
        """
        pass

    def test_list_image_restore_plans_plan_restore_image_get(self) -> None:
        """Test case for list_image_restore_plans_plan_restore_image_get

        List Image Restore Plans
        """
        pass

    def test_remove_restore_plan_agent_plan_restore_plan_id_remove_agent_agent_id_post(self) -> None:
        """Test case for remove_restore_plan_agent_plan_restore_plan_id_remove_agent_agent_id_post

        Remove Restore Plan Agent
        """
        pass

    def test_remove_restore_plan_schedule_plan_restore_plan_id_remove_schedule_schedule_id_post(self) -> None:
        """Test case for remove_restore_plan_schedule_plan_restore_plan_id_remove_schedule_schedule_id_post

        Remove Restore Plan Schedule
        """
        pass

    def test_update_file_restore_plans_plan_restore_file_plan_id_put(self) -> None:
        """Test case for update_file_restore_plans_plan_restore_file_plan_id_put

        Update File Restore Plans
        """
        pass

    def test_update_image_restore_plans_plan_restore_image_plan_id_put(self) -> None:
        """Test case for update_image_restore_plans_plan_restore_image_plan_id_put

        Update Image Restore Plans
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.pyd_message_type import PydMessageType


class TestPydMessageType(unittest.TestCase):
    """PydMessageType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPydMessageType(self):
        """Test PydMessageType"""
        # inst = PydMessageType()


if __name__ == "__main__":
    unittest.main()



"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from datetime import datetime
from pydantic import Field, StrictStr, field_validator
from typing import List, Optional
from typing_extensions import Annotated
from uuid import UUID
from cybee_sdk.api.models.generate_key_request import GenerateKeyRequest
from cybee_sdk.api.models.generated_api_key import GeneratedApiKey
from cybee_sdk.api.models.page_api_key import PageApiKey
from cybee_sdk.api.models.page_organization import PageOrganization
from cybee_sdk.api.models.pyd_generic_message import PydGenericMessage

from cybee_sdk.api.api_client import ApiClient, RequestSerialized
from cybee_sdk.api.api_response import ApiResponse
from cybee_sdk.api.rest import RESTResponseType


class IdentityApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def create_api_key_identity_keys_post(
        self,
        generate_key_request: GenerateKeyRequest,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GeneratedApiKey:
        """Create Api Key


        :param generate_key_request: (required)
        :type generate_key_request: GenerateKeyRequest
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._create_api_key_identity_keys_post_serialize(
            generate_key_request=generate_key_request,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "GeneratedApiKey",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def create_api_key_identity_keys_post_with_http_info(
        self,
        generate_key_request: GenerateKeyRequest,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GeneratedApiKey]:
        """Create Api Key


        :param generate_key_request: (required)
        :type generate_key_request: GenerateKeyRequest
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._create_api_key_identity_keys_post_serialize(
            generate_key_request=generate_key_request,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "GeneratedApiKey",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def create_api_key_identity_keys_post_without_preload_content(
        self,
        generate_key_request: GenerateKeyRequest,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Api Key


        :param generate_key_request: (required)
        :type generate_key_request: GenerateKeyRequest
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._create_api_key_identity_keys_post_serialize(
            generate_key_request=generate_key_request,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "GeneratedApiKey",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        return response_data.response

    def _create_api_key_identity_keys_post_serialize(
        self,
        generate_key_request,
        cbe_user_org_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if cbe_user_org_id is not None:
            _header_params["cbe-user-org-id"] = cbe_user_org_id
        # process the form parameters
        # process the body parameter
        if generate_key_request is not None:
            _body_params = generate_key_request

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(["application/json"])
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ["ZitadelWebAuthorizationBearer", "BearerToken"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/identity/keys/",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def list_all_api_keys_identity_keys_get(
        self,
        page: Optional[Annotated[int, Field(strict=True, ge=0)]] = None,
        per_page: Optional[Annotated[int, Field(le=50, strict=True, ge=1)]] = None,
        order_by: Optional[List[Optional[StrictStr]]] = None,
        id: Optional[List[UUID]] = None,
        name: Optional[StrictStr] = None,
        expiration_at_gt: Optional[datetime] = None,
        expiration_at_lt: Optional[datetime] = None,
        created_at_gt: Optional[datetime] = None,
        created_at_lt: Optional[datetime] = None,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PageApiKey:
        """List All Api Keys


        :param page:
        :type page: int
        :param per_page:
        :type per_page: int
        :param order_by:
        :type order_by: List[Optional[str]]
        :param id:
        :type id: List[UUID]
        :param name:
        :type name: str
        :param expiration_at_gt:
        :type expiration_at_gt: datetime
        :param expiration_at_lt:
        :type expiration_at_lt: datetime
        :param created_at_gt:
        :type created_at_gt: datetime
        :param created_at_lt:
        :type created_at_lt: datetime
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_all_api_keys_identity_keys_get_serialize(
            page=page,
            per_page=per_page,
            order_by=order_by,
            id=id,
            name=name,
            expiration_at_gt=expiration_at_gt,
            expiration_at_lt=expiration_at_lt,
            created_at_gt=created_at_gt,
            created_at_lt=created_at_lt,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PageApiKey",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def list_all_api_keys_identity_keys_get_with_http_info(
        self,
        page: Optional[Annotated[int, Field(strict=True, ge=0)]] = None,
        per_page: Optional[Annotated[int, Field(le=50, strict=True, ge=1)]] = None,
        order_by: Optional[List[Optional[StrictStr]]] = None,
        id: Optional[List[UUID]] = None,
        name: Optional[StrictStr] = None,
        expiration_at_gt: Optional[datetime] = None,
        expiration_at_lt: Optional[datetime] = None,
        created_at_gt: Optional[datetime] = None,
        created_at_lt: Optional[datetime] = None,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PageApiKey]:
        """List All Api Keys


        :param page:
        :type page: int
        :param per_page:
        :type per_page: int
        :param order_by:
        :type order_by: List[Optional[str]]
        :param id:
        :type id: List[UUID]
        :param name:
        :type name: str
        :param expiration_at_gt:
        :type expiration_at_gt: datetime
        :param expiration_at_lt:
        :type expiration_at_lt: datetime
        :param created_at_gt:
        :type created_at_gt: datetime
        :param created_at_lt:
        :type created_at_lt: datetime
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_all_api_keys_identity_keys_get_serialize(
            page=page,
            per_page=per_page,
            order_by=order_by,
            id=id,
            name=name,
            expiration_at_gt=expiration_at_gt,
            expiration_at_lt=expiration_at_lt,
            created_at_gt=created_at_gt,
            created_at_lt=created_at_lt,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PageApiKey",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def list_all_api_keys_identity_keys_get_without_preload_content(
        self,
        page: Optional[Annotated[int, Field(strict=True, ge=0)]] = None,
        per_page: Optional[Annotated[int, Field(le=50, strict=True, ge=1)]] = None,
        order_by: Optional[List[Optional[StrictStr]]] = None,
        id: Optional[List[UUID]] = None,
        name: Optional[StrictStr] = None,
        expiration_at_gt: Optional[datetime] = None,
        expiration_at_lt: Optional[datetime] = None,
        created_at_gt: Optional[datetime] = None,
        created_at_lt: Optional[datetime] = None,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List All Api Keys


        :param page:
        :type page: int
        :param per_page:
        :type per_page: int
        :param order_by:
        :type order_by: List[Optional[str]]
        :param id:
        :type id: List[UUID]
        :param name:
        :type name: str
        :param expiration_at_gt:
        :type expiration_at_gt: datetime
        :param expiration_at_lt:
        :type expiration_at_lt: datetime
        :param created_at_gt:
        :type created_at_gt: datetime
        :param created_at_lt:
        :type created_at_lt: datetime
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_all_api_keys_identity_keys_get_serialize(
            page=page,
            per_page=per_page,
            order_by=order_by,
            id=id,
            name=name,
            expiration_at_gt=expiration_at_gt,
            expiration_at_lt=expiration_at_lt,
            created_at_gt=created_at_gt,
            created_at_lt=created_at_lt,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PageApiKey",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        return response_data.response

    def _list_all_api_keys_identity_keys_get_serialize(
        self,
        page,
        per_page,
        order_by,
        id,
        name,
        expiration_at_gt,
        expiration_at_lt,
        created_at_gt,
        created_at_lt,
        cbe_user_org_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            "order_by": "multi",
            "id": "multi",
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if page is not None:
            _query_params.append(("page", page))

        if per_page is not None:
            _query_params.append(("per_page", per_page))

        if order_by is not None:
            _query_params.append(("order_by", order_by))

        if id is not None:
            _query_params.append(("id", id))

        if name is not None:
            _query_params.append(("name", name))

        if expiration_at_gt is not None:
            if isinstance(expiration_at_gt, datetime):
                _query_params.append(
                    ("expiration_at_gt", expiration_at_gt.strftime(self.api_client.configuration.datetime_format))
                )
            else:
                _query_params.append(("expiration_at_gt", expiration_at_gt))

        if expiration_at_lt is not None:
            if isinstance(expiration_at_lt, datetime):
                _query_params.append(
                    ("expiration_at_lt", expiration_at_lt.strftime(self.api_client.configuration.datetime_format))
                )
            else:
                _query_params.append(("expiration_at_lt", expiration_at_lt))

        if created_at_gt is not None:
            if isinstance(created_at_gt, datetime):
                _query_params.append(
                    ("created_at_gt", created_at_gt.strftime(self.api_client.configuration.datetime_format))
                )
            else:
                _query_params.append(("created_at_gt", created_at_gt))

        if created_at_lt is not None:
            if isinstance(created_at_lt, datetime):
                _query_params.append(
                    ("created_at_lt", created_at_lt.strftime(self.api_client.configuration.datetime_format))
                )
            else:
                _query_params.append(("created_at_lt", created_at_lt))

        # process the header parameters
        if cbe_user_org_id is not None:
            _header_params["cbe-user-org-id"] = cbe_user_org_id
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # authentication setting
        _auth_settings: List[str] = ["ZitadelWebAuthorizationBearer", "BearerToken"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/identity/keys/",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def list_all_organization_identity_organization_get(
        self,
        page: Optional[Annotated[int, Field(strict=True, ge=0)]] = None,
        per_page: Optional[Annotated[int, Field(le=50, strict=True, ge=1)]] = None,
        order_by: Optional[List[StrictStr]] = None,
        id: Optional[List[UUID]] = None,
        display_name: Optional[StrictStr] = None,
        created_at_gt: Optional[datetime] = None,
        created_at_lt: Optional[datetime] = None,
        updated_at_gt: Optional[datetime] = None,
        updated_at_lt: Optional[datetime] = None,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PageOrganization:
        """List All Organization


        :param page:
        :type page: int
        :param per_page:
        :type per_page: int
        :param order_by:
        :type order_by: List[str]
        :param id:
        :type id: List[UUID]
        :param display_name:
        :type display_name: str
        :param created_at_gt:
        :type created_at_gt: datetime
        :param created_at_lt:
        :type created_at_lt: datetime
        :param updated_at_gt:
        :type updated_at_gt: datetime
        :param updated_at_lt:
        :type updated_at_lt: datetime
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_all_organization_identity_organization_get_serialize(
            page=page,
            per_page=per_page,
            order_by=order_by,
            id=id,
            display_name=display_name,
            created_at_gt=created_at_gt,
            created_at_lt=created_at_lt,
            updated_at_gt=updated_at_gt,
            updated_at_lt=updated_at_lt,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PageOrganization",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def list_all_organization_identity_organization_get_with_http_info(
        self,
        page: Optional[Annotated[int, Field(strict=True, ge=0)]] = None,
        per_page: Optional[Annotated[int, Field(le=50, strict=True, ge=1)]] = None,
        order_by: Optional[List[StrictStr]] = None,
        id: Optional[List[UUID]] = None,
        display_name: Optional[StrictStr] = None,
        created_at_gt: Optional[datetime] = None,
        created_at_lt: Optional[datetime] = None,
        updated_at_gt: Optional[datetime] = None,
        updated_at_lt: Optional[datetime] = None,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PageOrganization]:
        """List All Organization


        :param page:
        :type page: int
        :param per_page:
        :type per_page: int
        :param order_by:
        :type order_by: List[str]
        :param id:
        :type id: List[UUID]
        :param display_name:
        :type display_name: str
        :param created_at_gt:
        :type created_at_gt: datetime
        :param created_at_lt:
        :type created_at_lt: datetime
        :param updated_at_gt:
        :type updated_at_gt: datetime
        :param updated_at_lt:
        :type updated_at_lt: datetime
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_all_organization_identity_organization_get_serialize(
            page=page,
            per_page=per_page,
            order_by=order_by,
            id=id,
            display_name=display_name,
            created_at_gt=created_at_gt,
            created_at_lt=created_at_lt,
            updated_at_gt=updated_at_gt,
            updated_at_lt=updated_at_lt,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PageOrganization",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def list_all_organization_identity_organization_get_without_preload_content(
        self,
        page: Optional[Annotated[int, Field(strict=True, ge=0)]] = None,
        per_page: Optional[Annotated[int, Field(le=50, strict=True, ge=1)]] = None,
        order_by: Optional[List[StrictStr]] = None,
        id: Optional[List[UUID]] = None,
        display_name: Optional[StrictStr] = None,
        created_at_gt: Optional[datetime] = None,
        created_at_lt: Optional[datetime] = None,
        updated_at_gt: Optional[datetime] = None,
        updated_at_lt: Optional[datetime] = None,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List All Organization


        :param page:
        :type page: int
        :param per_page:
        :type per_page: int
        :param order_by:
        :type order_by: List[str]
        :param id:
        :type id: List[UUID]
        :param display_name:
        :type display_name: str
        :param created_at_gt:
        :type created_at_gt: datetime
        :param created_at_lt:
        :type created_at_lt: datetime
        :param updated_at_gt:
        :type updated_at_gt: datetime
        :param updated_at_lt:
        :type updated_at_lt: datetime
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_all_organization_identity_organization_get_serialize(
            page=page,
            per_page=per_page,
            order_by=order_by,
            id=id,
            display_name=display_name,
            created_at_gt=created_at_gt,
            created_at_lt=created_at_lt,
            updated_at_gt=updated_at_gt,
            updated_at_lt=updated_at_lt,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PageOrganization",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        return response_data.response

    def _list_all_organization_identity_organization_get_serialize(
        self,
        page,
        per_page,
        order_by,
        id,
        display_name,
        created_at_gt,
        created_at_lt,
        updated_at_gt,
        updated_at_lt,
        cbe_user_org_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            "order_by": "multi",
            "id": "multi",
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if page is not None:
            _query_params.append(("page", page))

        if per_page is not None:
            _query_params.append(("per_page", per_page))

        if order_by is not None:
            _query_params.append(("order_by", order_by))

        if id is not None:
            _query_params.append(("id", id))

        if display_name is not None:
            _query_params.append(("display_name", display_name))

        if created_at_gt is not None:
            if isinstance(created_at_gt, datetime):
                _query_params.append(
                    ("created_at_gt", created_at_gt.strftime(self.api_client.configuration.datetime_format))
                )
            else:
                _query_params.append(("created_at_gt", created_at_gt))

        if created_at_lt is not None:
            if isinstance(created_at_lt, datetime):
                _query_params.append(
                    ("created_at_lt", created_at_lt.strftime(self.api_client.configuration.datetime_format))
                )
            else:
                _query_params.append(("created_at_lt", created_at_lt))

        if updated_at_gt is not None:
            if isinstance(updated_at_gt, datetime):
                _query_params.append(
                    ("updated_at_gt", updated_at_gt.strftime(self.api_client.configuration.datetime_format))
                )
            else:
                _query_params.append(("updated_at_gt", updated_at_gt))

        if updated_at_lt is not None:
            if isinstance(updated_at_lt, datetime):
                _query_params.append(
                    ("updated_at_lt", updated_at_lt.strftime(self.api_client.configuration.datetime_format))
                )
            else:
                _query_params.append(("updated_at_lt", updated_at_lt))

        # process the header parameters
        if cbe_user_org_id is not None:
            _header_params["cbe-user-org-id"] = cbe_user_org_id
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # authentication setting
        _auth_settings: List[str] = ["ZitadelWebAuthorizationBearer", "BearerToken"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/identity/organization/",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def revoke_api_key_identity_keys_key_id_delete(
        self,
        key_id: StrictStr,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PydGenericMessage:
        """Revoke Api Key


        :param key_id: (required)
        :type key_id: str
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._revoke_api_key_identity_keys_key_id_delete_serialize(
            key_id=key_id,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PydGenericMessage",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def revoke_api_key_identity_keys_key_id_delete_with_http_info(
        self,
        key_id: StrictStr,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PydGenericMessage]:
        """Revoke Api Key


        :param key_id: (required)
        :type key_id: str
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._revoke_api_key_identity_keys_key_id_delete_serialize(
            key_id=key_id,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PydGenericMessage",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def revoke_api_key_identity_keys_key_id_delete_without_preload_content(
        self,
        key_id: StrictStr,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Revoke Api Key


        :param key_id: (required)
        :type key_id: str
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._revoke_api_key_identity_keys_key_id_delete_serialize(
            key_id=key_id,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PydGenericMessage",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        return response_data.response

    def _revoke_api_key_identity_keys_key_id_delete_serialize(
        self,
        key_id,
        cbe_user_org_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if key_id is not None:
            _path_params["key_id"] = key_id
        # process the query parameters
        # process the header parameters
        if cbe_user_org_id is not None:
            _header_params["cbe-user-org-id"] = cbe_user_org_id
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # authentication setting
        _auth_settings: List[str] = ["ZitadelWebAuthorizationBearer", "BearerToken"]

        return self.api_client.param_serialize(
            method="DELETE",
            resource_path="/identity/keys/{key_id}/",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



# flake8: noqa

# import apis into api package
from cybee_sdk.api.api.agents_api import AgentsApi
from cybee_sdk.api.api.cmdb_api import CmdbApi
from cybee_sdk.api.api.identity_api import IdentityApi
from cybee_sdk.api.api.notification_api import NotificationApi
from cybee_sdk.api.api.plans_backup_api import PlansBackupApi
from cybee_sdk.api.api.plans_restore_api import PlansRestoreApi
from cybee_sdk.api.api.plans_schedule_api import PlansScheduleApi
from cybee_sdk.api.api.storage_account_api import StorageAccountApi
from cybee_sdk.api.api.storage_destination_api import StorageDestinationApi
from cybee_sdk.api.api.storage_repository_api import StorageRepositoryApi



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class PrePostRunScript(BaseModel):
    """
    PrePostRunScript
    """  # noqa: E501

    executor: StrictStr
    args: Optional[List[StrictStr]] = None
    envs: Optional[Dict[str, StrictStr]] = None
    script_path: StrictStr
    script: Optional[StrictStr] = None
    abort_if_fail: StrictBool
    __properties: ClassVar[List[str]] = ["executor", "args", "envs", "script_path", "script", "abort_if_fail"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PrePostRunScript from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if args (nullable) is None
        # and model_fields_set contains the field
        if self.args is None and "args" in self.model_fields_set:
            _dict["args"] = None

        # set to None if envs (nullable) is None
        # and model_fields_set contains the field
        if self.envs is None and "envs" in self.model_fields_set:
            _dict["envs"] = None

        # set to None if script (nullable) is None
        # and model_fields_set contains the field
        if self.script is None and "script" in self.model_fields_set:
            _dict["script"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PrePostRunScript from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "executor": obj.get("executor"),
                "args": obj.get("args"),
                "envs": obj.get("envs"),
                "script_path": obj.get("script_path"),
                "script": obj.get("script"),
                "abort_if_fail": obj.get("abort_if_fail"),
            }
        )
        return _obj



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.file_backup_plan import FileBackupPlan


class TestFileBackupPlan(unittest.TestCase):
    """FileBackupPlan unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileBackupPlan:
        """Test FileBackupPlan
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `FileBackupPlan`
        """
        model = FileBackupPlan()
        if include_optional:
            return FileBackupPlan(
                id = '',
                name = '',
                description = '',
                repo_id = '',
                config = cybee_sdk.api.models.restic_backup.ResticBackup(
                    global_options = null, 
                    source_paths = [
                        ''
                        ], 
                    exclude = [
                        ''
                        ], 
                    exclude_caches = True, 
                    exclude_if_present = [
                        ''
                        ], 
                    exclude_larger_than = null, 
                    iexclude = [
                        ''
                        ], ),
                retention_settings = cybee_sdk.api.models.retention_settings.RetentionSettings(
                    keep_last = 0.0, 
                    keep_hourly = 0.0, 
                    keep_daily = 0.0, 
                    keep_weekly = 0.0, 
                    keep_monthly = 0.0, 
                    keep_yearly = 0.0, 
                    keep_within_as_secs = 0.0, 
                    keep_within_hourly_as_secs = 0.0, 
                    keep_within_daily_as_secs = 0.0, 
                    keep_within_weekly_as_secs = 0.0, 
                    keep_within_monthly_as_secs = 0.0, 
                    keep_within_yearly_as_secs = 0.0, ),
                schedule_enabled = True,
                schedule_configs = [
                    ''
                    ],
                last_executed = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                timestamps = cybee_sdk.api.models.time_stamps.TimeStamps(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                affected_agents = [
                    ''
                    ],
                pre_script = cybee_sdk.api.models.pre_post_run_script.PrePostRunScript(
                    executor = '', 
                    args = [
                        ''
                        ], 
                    envs = {
                        'key' : ''
                        }, 
                    script_path = '', 
                    script = '', 
                    abort_if_fail = True, ),
                post_script = cybee_sdk.api.models.pre_post_run_script.PrePostRunScript(
                    executor = '', 
                    args = [
                        ''
                        ], 
                    envs = {
                        'key' : ''
                        }, 
                    script_path = '', 
                    script = '', 
                    abort_if_fail = True, )
            )
        else:
            return FileBackupPlan(
                id = '',
                name = '',
                repo_id = '',
                config = cybee_sdk.api.models.restic_backup.ResticBackup(
                    global_options = null, 
                    source_paths = [
                        ''
                        ], 
                    exclude = [
                        ''
                        ], 
                    exclude_caches = True, 
                    exclude_if_present = [
                        ''
                        ], 
                    exclude_larger_than = null, 
                    iexclude = [
                        ''
                        ], ),
                timestamps = cybee_sdk.api.models.time_stamps.TimeStamps(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
        )
        """

    def testFileBackupPlan(self):
        """Test FileBackupPlan"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.page_backup_plan_run import PageBackupPlanRun


class TestPageBackupPlanRun(unittest.TestCase):
    """PageBackupPlanRun unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageBackupPlanRun:
        """Test PageBackupPlanRun
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `PageBackupPlanRun`
        """
        model = PageBackupPlanRun()
        if include_optional:
            return PageBackupPlanRun(
                page = 56,
                per_page = 56,
                total_items = 56,
                total_pages = 56,
                items = [
                    cybee_sdk.api.models.backup_plan_run.BackupPlanRun(
                        id = '', 
                        task_id = '', 
                        snapshot_id = '', 
                        agent_id = '', 
                        programmed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        repository_id = '', 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        plan_config = '', 
                        plan_id = '', 
                        plan_type = '', 
                        status = null, 
                        snapshots = [
                            cybee_sdk.api.models.snapshot.Snapshot(
                                id = '', 
                                files_new = 0.0, 
                                files_changed = 0.0, 
                                files_unmodified = 0.0, 
                                dirs_new = 0.0, 
                                dirs_changed = 0.0, 
                                dirs_unmodified = 0.0, 
                                data_blobs = 0.0, 
                                tree_blobs = 0.0, 
                                data_added = 0.0, 
                                data_added_packed = 0.0, 
                                total_files_processed = 0.0, 
                                total_bytes_processed = 0.0, 
                                total_duration = 0.0, 
                                snapshot_id = '', 
                                backup_paths = [
                                    ''
                                    ], )
                            ], 
                        errors = [
                            ''
                            ], )
                    ]
            )
        else:
            return PageBackupPlanRun(
                page = 56,
                per_page = 56,
                total_items = 56,
                items = [
                    cybee_sdk.api.models.backup_plan_run.BackupPlanRun(
                        id = '', 
                        task_id = '', 
                        snapshot_id = '', 
                        agent_id = '', 
                        programmed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        repository_id = '', 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        plan_config = '', 
                        plan_id = '', 
                        plan_type = '', 
                        status = null, 
                        snapshots = [
                            cybee_sdk.api.models.snapshot.Snapshot(
                                id = '', 
                                files_new = 0.0, 
                                files_changed = 0.0, 
                                files_unmodified = 0.0, 
                                dirs_new = 0.0, 
                                dirs_changed = 0.0, 
                                dirs_unmodified = 0.0, 
                                data_blobs = 0.0, 
                                tree_blobs = 0.0, 
                                data_added = 0.0, 
                                data_added_packed = 0.0, 
                                total_files_processed = 0.0, 
                                total_bytes_processed = 0.0, 
                                total_duration = 0.0, 
                                snapshot_id = '', 
                                backup_paths = [
                                    ''
                                    ], )
                            ], 
                        errors = [
                            ''
                            ], )
                    ],
        )
        """

    def testPageBackupPlanRun(self):
        """Test PageBackupPlanRun"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.restic_restore import ResticRestore


class TestResticRestore(unittest.TestCase):
    """ResticRestore unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResticRestore:
        """Test ResticRestore
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `ResticRestore`
        """
        model = ResticRestore()
        if include_optional:
            return ResticRestore(
                global_options = cybee_sdk.api.models.global_restic_options.GlobalResticOptions(
                    cache_dir = '', 
                    limit_download = 0.0, 
                    limit_upload = 0.0, ),
                exclude = [
                    ''
                    ],
                include = [
                    ''
                    ],
                iexclude = [
                    ''
                    ],
                iinclude = [
                    ''
                    ],
                host = '',
                path = '',
                tag = [
                    ''
                    ],
                sparse = True,
                target = '',
                verify = True,
                snapshot_id = ''
            )
        else:
            return ResticRestore(
                global_options = cybee_sdk.api.models.global_restic_options.GlobalResticOptions(
                    cache_dir = '', 
                    limit_download = 0.0, 
                    limit_upload = 0.0, ),
                target = '',
                snapshot_id = '',
        )
        """

    def testResticRestore(self):
        """Test ResticRestore"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
